@@ -1,12 +1,12 @@
 from qtpy.QtCore import QThread
-from pymodaq.daq_viewer.utility_classes import DAQ_Viewer_base
+from pymodaq.control_modules.viewer_utility_classes import DAQ_Viewer_base, main
 import numpy as np
 from easydict import EasyDict as edict
 from collections import OrderedDict
 from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo
 from pymodaq.daq_utils.daq_utils import gauss1D
-from pymodaq.daq_viewer.utility_classes import comon_parameters
-from .daq_1Dviewer_Mock_spectro import DAQ_1DViewer_Mock_spectro
+from pymodaq.control_modules.viewer_utility_classes import comon_parameters
+from pymodaq_plugins.daq_viewer_plugins.plugins_1D.daq_1Dviewer_Mock_spectro import DAQ_1DViewer_Mock_spectro
 
 
 class DAQ_1DViewer_Mock(DAQ_1DViewer_Mock_spectro):
@@ -47,3 +47,7 @@ class DAQ_1DViewer_Mock(DAQ_1DViewer_Mock_spectro):
         self.settings.child(('exposure_ms')).hide()
 
         return self.status
+
+
+if __name__ == '__main__':
+    main(__file__)
