@@ -1,7 +1,7 @@
 from qtpy.QtCore import Signal
 from easydict import EasyDict as edict
 from collections import OrderedDict
-from pymodaq.daq_viewer.utility_classes import DAQ_Viewer_TCP_server
+from pymodaq.control_modules.viewer_utility_classes import DAQ_Viewer_TCP_server
 from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, DataFromPlugins, Axis
 
 
