@@ -2,11 +2,11 @@ from qtpy.QtCore import QThread
 from qtpy import QtWidgets
 import numpy as np
 import pymodaq.daq_utils.daq_utils as utils
-from pymodaq.daq_viewer.utility_classes import DAQ_Viewer_base
+from pymodaq.control_modules.viewer_utility_classes import DAQ_Viewer_base
 from easydict import EasyDict as edict
 from collections import OrderedDict
 from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, Axis, DataFromPlugins, NavAxis
-from pymodaq.daq_viewer.utility_classes import comon_parameters
+from pymodaq.control_modules.viewer_utility_classes import comon_parameters
 
 
 class DAQ_NDViewer_Mock(DAQ_Viewer_base):
